==> freecad_0.18.4+dfsg2.orig.tar.xz: FreeCAD-0.18.4/src/Mod/Tux/Resources/translations/Tux_sv-SE.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="sv-SE" sourcelanguage="en">
  <context>
    <name>NavigationIndicator</name>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="62"/>
      <source>Select</source>
      <translation>Markera</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="63"/>
      <source>Zoom</source>
      <translation>Zooma</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="64"/>
      <source>Rotate</source>
      <translation>Rotera</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="65"/>
      <source>Pan</source>
      <translation>Panorera</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="66"/>
      <source>Tilt</source>
      <translation>Luta</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="67"/>
      <source>Navigation style</source>
      <translation>Navigationsstil</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="68"/>
      <source>Page Up or Page Down key.</source>
      <translation>Page Up eller Page Down-tangenten.</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="69"/>
      <source>Rotation focus</source>
      <translation>Rotationsfokus</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="71"/>
      <source>Middle mouse button.</source>
      <translation>Mus-knappen i mitten.</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="74"/>
      <source>Navigation style not recognized.</source>
      <translation>Navigationsstilen känns inte igen.</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="291"/>
      <source>Settings</source>
      <translation>Inställningar</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="292"/>
      <source>Orbit style</source>
      <translation>Orbit stil</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="293"/>
      <source>Compact</source>
      <translation>Kompakt</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="294"/>
      <source>Tooltip</source>
      <translation>Verktygstips</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="295"/>
      <source>Turntable</source>
      <translation>Skivtallrik</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="296"/>
      <source>Trackball</source>
      <translation>Trackball</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="297"/>
      <source>Undefined</source>
      <translation>Odefinierad</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="70"/>
      <source>Middle mouse button or H key.</source>
      <translation>Mittersta musknappen eller H-tangenten.</translation>
    </message>
  </context>
</TS>

==> freecad_0.19.2+dfsg1.orig.tar.xz: FreeCAD-0.19.2/src/Mod/Tux/Resources/translations/Tux_sv-SE.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="1.1" language="sv-SE" sourcelanguage="en">
  <context>
    <name>NavigationIndicator</name>
    <message>
      <location filename="NavigationIndicatorGui.py" line="63"/>
      <source>Select</source>
      <translation>Markera</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="64"/>
      <source>Zoom</source>
      <translation>Zooma</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="65"/>
      <source>Rotate</source>
      <translation>Rotera</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="66"/>
      <source>Pan</source>
      <translation>Panorera</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="67"/>
      <source>Tilt</source>
      <translation>Luta</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="68"/>
      <source>Navigation style</source>
      <translation>Navigationsstil</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="69"/>
      <source>Page Up or Page Down key.</source>
      <translation>Page Up eller Page Down-tangenten.</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="70"/>
      <source>Rotation focus</source>
      <translation>Rotationsfokus</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="73"/>
      <source>Middle mouse button.</source>
      <translation>Mus-knappen i mitten.</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="76"/>
      <source>Navigation style not recognized.</source>
      <translation>Navigationsstilen känns inte igen.</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="291"/>
      <source>Settings</source>
      <translation>Inställningar</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="292"/>
      <source>Orbit style</source>
      <translation>Orbit stil</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="293"/>
      <source>Compact</source>
      <translation>Kompakt</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="294"/>
      <source>Tooltip</source>
      <translation>Verktygstips</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="295"/>
      <source>Turntable</source>
      <translation>Skivtallrik</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="296"/>
      <source>Trackball</source>
      <translation>Trackball</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="297"/>
      <source>Undefined</source>
      <translation>Odefinierad</translation>
    </message>
    <message>
      <location filename="NavigationIndicatorGui.py" line="71"/>
      <source>Middle mouse button or H key.</source>
      <translation>Mittersta musknappen eller H-tangenten.</translation>
    </message>
  </context>
</TS>
